<?php
// Function.php

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */

define( 'NX_ALPHA_ONE_THEMEROOT', get_stylesheet_directory_uri() );
define( 'NX_ALPHA_ONE_IMAGES', NX_ALPHA_ONE_THEMEROOT . '/images' );
define( 'NX_ALPHA_ONE_SCRIPTS', NX_ALPHA_ONE_THEMEROOT . '/js' );
define( 'NX_ALPHA_ONE_STYLESHEET', NX_ALPHA_ONE_THEMEROOT . '/css' );



/**
 * ----------------------------------------------------------------------------------------
 * 2.0 - Define constants.  
 * ----------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'alpha_nx_one_setup' ) ) {
	function alpha_nx_one_setup() {
		 global $content_width;		 
		if ( ! isset( $content_width ) ) $content_width = 900;
		/**
		 * Make the theme available for translation.
		 */
		load_theme_textdomain('alpha-nx-one',get_template_directory() . '/languages');

		/**
		 * Add support for post formats.
		 */
		add_theme_support( 'post-formats',
			array(
				'gallery',
				'link',
				'image',
				'quote',
				'video',
				'audio'
			)
		);

		
		/**
		 * Add support for automatic feed links.
		 */
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( "title-tag" );
		add_theme_support( 'custom-header', array(
		'header-text' => false,
		'flex-height' => true,
		'flex-width' => true,
		'random-default' => true,
		'height' => apply_filters( 'alpha_nx_one_image_height',500 ),
	) );
		/**
		 * Add support for post thumbnails.
		 */
		add_theme_support( 'post-thumbnails' );		
		
		
		 // Setup the WordPress core custom background feature.
    
		add_theme_support( 'custom-background', apply_filters( 'alpha_nx_one_custom_background_args', array(
        'default-color' => 'ffffff',
        'default-image' => '',
		) ) );

		/**
		 * Register nav menus.
		 */
		//add_theme_support('menus');
		register_nav_menus(
			array(
				'main-menu' => __( 'Primary Menu', 'alpha-nx-one' )
			)
		);
	}

	add_action( 'after_setup_theme', 'alpha_nx_one_setup' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 3.0 - Display meta information for a specific post. alpha_nx_one
 * ----------------------------------------------------------------------------------------
 */
 
if ( ! function_exists( 'alpha_nx_one_post_meta' ) ) {
	function alpha_nx_one_post_meta() {
		echo '<ul id="post_details">';

		if ( get_post_type() == 'post' ) {
			// If the post is sticky, mark it.
			if ( is_sticky() ) {
				echo '<!-- fa-lg --><li class="meta-featured-post"><i class="fa fa-thumb-tack"></i> ' . __( 'Sticky', 'alpha-nx-one' ) . ' </li>';
			}

			// Get the post author.
			printf(
				'<li class="meta-author"><i class="fa fa-user"></i><a href="%1$s" rel="author">%2$s</a></li>',
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				get_the_author()
			);

			// Get the date.
			echo '<li class="meta-date"><i class="fa fa-calendar"></i> ' . get_the_date() . ' </li>';

			// The categories.
			$category_list = get_the_category_list( ', ' );
			if ( $category_list ) {
				echo '<li class="meta-categories"><span><i class="fa fa-folder-open"></i> ' . $category_list . ' </span></li>';
			}

			// Comments link.
			if ( comments_open()) :
				echo '<li class="meta-reply">';
				echo '<span><i class="fa fa-comments-o"></i>';
				
				comments_popup_link( __( 'Leave a comment', 'alpha-nx-one' ), __( 'One comment', 'alpha-nx-one' ), __( 'View all % comments', 'alpha-nx-one' ) );
				
				echo '</span>';
				echo '</li>';
			endif;

			// Edit link.
			if ( is_user_logged_in() ) {
				echo '<li>';
				edit_post_link( __( 'Edit', 'alpha-nx-one' ), '<span class="meta-edit"><i class="fa fa-edit"></i>', '</span>' );
				echo '</li>';
			}
		}
	echo '</ul>';
	}
}


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Display navigation to the next/previous set of posts.
 * ----------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'alpha_nx_one_paging_nav' ) ) :
	function alpha_nx_one_paging_nav() {
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		}

		$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
		$pagenum_link = html_entity_decode( get_pagenum_link() );
		$query_args   = array();
		$url_parts    = explode( '?', $pagenum_link );

		if ( isset( $url_parts[1] ) ) {
			wp_parse_str( $url_parts[1], $query_args );
		}
		$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
		$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

		$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
		$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
		'base'     => $pagenum_link,
		'format'   => $format,
		'total'    => $GLOBALS['wp_query']->max_num_pages,
		'current'  => $paged,
		'mid_size' => 3,
		'add_args' => array_map( 'urlencode', $query_args ),
		'prev_text' => __( '&larr; Previous', '' ),
		'next_text' => __( 'Next &rarr;', 'alpha-nx-one' ),
		'type'      => 'list',
	) );

	if ( $links ) :
	?>
	<nav id="paging_navigation" role="navigation">
			<?php echo $links; ?>
	</nav><!-- .navigation -->
	<?php
	endif;
}
endif;


/**
 * ----------------------------------------------------------------------------------------
 * 5.0 - Register the widget areas.
 * ----------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'alpha_nx_one_widget_init' ) ) {
	function alpha_nx_one_widget_init() {
		if ( function_exists( 'register_sidebar' ) ) {
			register_sidebar(
				array(
					'name' => __( 'Main Widget Area', 'alpha-nx-one' ),
					'id' => 'sidebar-1',
					'description' => __( 'Appears on posts and pages.', 'alpha-nx-one' ),
					'before_widget' => '<div id="widget_sidebar" class="widget %2$s">',
					'after_widget' => '</div> <!-- end widget -->',
					'before_title' => '<h3 class="widget-title">',
					'after_title' => '</h3><div class="widget-line"></div>',
				)
			);
			register_sidebar(
				array(
					'name' => __( 'Footer Widget Area', 'alpha-nx-one' ),
					'id' => 'sidebar-2',
					'description' => __( 'Appears on the footer.', 'alpha-nx-one' ),
					'before_widget' => '<div id="widget_footer" class="widget footer_content %2$s">',
					'after_widget' => '</div> <!-- end widget -->',
					'before_title' => '<h3 class="widget-title_2">',
					'after_title' => '</h3>',
				)
			);
			
		}
	}

	add_action( 'widgets_init', 'alpha_nx_one_widget_init' );
}


 /**
 * ----------------------------------------------------------------------------------------
 *  6.0 - Add read more in post without page and single page
 * ----------------------------------------------------------------------------------------
 */


 function alpha_nx_one_excerpt_more( $more ) {
	return '<div id="read_more_container"><div id="read_more"> <span><a href="'.esc_url( get_permalink( get_the_ID() )). '">' . __('Read More', 'alpha-nx-one') . '</span><i class="fa fa-long-arrow-right fa-lg"></i></a></div></div>';
}
add_filter( 'excerpt_more', 'alpha_nx_one_excerpt_more' );
 

/**
 * ----------------------------------------------------------------------------------------
 * 7.0 - Breadcrumbs
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_nx_one_breadcrumbs' ) ) {
	function alpha_nx_one_breadcrumbs() {
 
        global $post;
 
        if (!is_home()) {
 
            echo "<a href='";
            echo esc_url( home_url('/') );
            echo "'>";
            echo "Home";
            echo "</a>";
 
            if (is_category() || is_single()) {
 
                echo '   <i class="fa fa-angle-double-right"></i>';
                $cats = get_the_category( $post->ID );
 
                foreach ( $cats as $cat ){
                    echo $cat->cat_name;
                    echo '   <i class="fa fa-angle-double-right"></i>';
                }
                if (is_single()) {
                    the_title();
                }
            } 
			elseif (is_page()) {
 
                if($post->post_parent){
                    $anc = get_post_ancestors( $post->ID );
                    $anc_link = get_page_link( $post->post_parent );
 
                    foreach ( $anc as $ancestor ) {
                        $output = " > <a href=".esc_url($anc_link).">".get_the_title($ancestor).'</a>   <i class="fa fa-angle-double-right"></i> ';
                    }
 
                    //echo $output;
                    the_title();  } 
				 else {
                    echo '<i class="fa fa-angle-double-right"></i> ';
                    echo the_title();
				}
			}
		}
	
    elseif (is_tag()) {single_tag_title();}
    elseif (is_day()) {echo"Archive: "; get_the_time('F jS, Y'); echo'</li>';}
    elseif (is_month()) {echo"Archive: "; get_the_time('F, Y'); echo'</li>';}
    elseif (is_year()) {echo"Archive: "; get_the_time('Y'); echo'</li>';}
    elseif (is_author()) {echo"Author's archive: "; echo'</li>';}
    elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {echo "Blogarchive: "; echo'';}
    elseif (is_search()) {echo"Search results: "; } 
	
	}
	
}
 
 if ( ! function_exists( 'alpha_nx_one_post_title' ) ) {
	function alpha_nx_one_post_title() {
		
		global $post;
		
		if (!is_home()) {
			if (is_single()) {
                    the_title();
                }            
			elseif (is_page()) {
 
                if($post->post_parent){
                    $anc = get_post_ancestors( $post->ID );
                    $anc_link = get_page_link( $post->post_parent );
 
                    foreach ( $anc as $ancestor ) {
                        $output = " > <a href=".esc_url($anc_link).">".get_the_title($ancestor)."</a> > ";
                    }
 
                    //echo $output;
                    the_title();  } 
				 else {
                    
                    echo the_title();
				}
			}
		}
		
	}
 }
 
 /**
 * ----------------------------------------------------------------------------------------
 * 8.0 - Add them option in wordpress
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'redux_disable_dev_mode_plugin' ) ) {
        function redux_disable_dev_mode_plugin( $redux ) {
            if ( $redux->args['opt_name'] != 'redux_demo' ) {
                $redux->args['dev_mode'] = false;
            }
        }

        add_action( 'redux/construct', 'redux_disable_dev_mode_plugin' );
    }

if (!isset($redux_demo)){
	require_once(dirname(__FILE__) . '/theme_admin.php');
}

// Show recommended plugin and install it

include 'tgm/tgm-init.php';

	
 /**
 * ----------------------------------------------------------------------------------------
 * 09.0 - Others
 * ----------------------------------------------------------------------------------------
 */


// setting page
function alpha_nx_one_custom_options(){ 

	global $alpha_nx_one;		

	 //add Favicon and Apple Icons

if(isset($alpha_nx_one['favicon']['url'])){
	
echo '<link rel="shortcut icon" href="'.esc_url($alpha_nx_one['favicon']['url']).'">';

}
if(isset($alpha_nx_one['apple_touch_icon']['url'])){
echo '<link rel="apple-touch-icon" href="'.esc_url($alpha_nx_one['apple_touch_icon']['url']).'">';}
?> 
 <style>
	<?php if($alpha_nx_one['date_and_time']=='0'){echo '#post_details .meta-date{display:none;}';}?>
	<?php if(isset($alpha_nx_one['Comments'])){
	if($alpha_nx_one['Comments']=='0'){	echo '#post_details .meta-reply{display:none;}';} } ?>	
	<?php if(isset($alpha_nx_one['custom_css'])){ echo strip_tags($alpha_nx_one['custom_css']); } ?>
	#site_title h1 a,#site_title p{<?php if(get_header_textcolor()=='blank') { echo 'visibility: hidden;'; } else { ?> color:#<?php header_textcolor();  } ?>}
	<?php if(!isset($alpha_nx_one['footer_font_color'])){echo'#copyright p a,.footer_color p,.footer_color p a,.footer_color span,.footer_color span a,.footer_color a,.footer_color p span,#widget_footer h3,#widget_footer ul li a,#widget_footer caption,#widget_footer .cat-item a:hover{color:#fff;}'; } ?>
	<?php if(!isset($alpha_nx_one['color'])){echo'#header_nav ul.menu li a:hover, .sub-menu li a:hover, .content_header h1 a:hover, #post_details li:hover, #post_details li a:hover, .widget-title:hover, #widget_footer h3:hover,#header_nav .menu .current-menu-item a,.menu .current-menu-item a, #widget_sidebar ul li a:hover,#copyright p a,#header_nav div.menu ul li a:hover,.children li a:hover{color:#e04028;}'; } ?>
	<?php if(!isset($alpha_nx_one['all_button_bg'])){echo'#read_more, #paging_navigation ul.page-numbers li  span.current , #paging_navigation ul.page-numbers li  a:hover, #widget_footer  input[type="submit"], #widget_footer  input[type="button"], #widget_footer ul.menu li:hover, #widget_footer .cat-item:hover, #widget_footer .tagcloud a:hover{background-color:#e04028;}'; } ?>


</style>
 <?php 
}

add_action('wp_head','alpha_nx_one_custom_options'); 

function alpha_nx_one_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'alpha_nx_one_add_editor_styles' );


function alpha_nx_one_canonical_for_comments() {
  global $cpage, $post;
  if ( $cpage > 1 ) :
    echo "n";
      echo "<link rel='canonical' href='";
      echo get_permalink( $post->ID );
      echo "' />n";
   endif;
}

add_action( 'wp_head', 'alpha_nx_one_canonical_for_comments' );


add_filter('widget_tag_cloud_args','alpha_nx_one_set_tag_cloud_sizes');
function alpha_nx_one_set_tag_cloud_sizes($args) {
$args['smallest'] = 8;
$args['largest'] = 8;
return $args; }

 /**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_nx_one_header_scripts' ) ) {
	function alpha_nx_one_header_scripts() {
		
		// Adds support for pages with threaded comments
		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
			

		// Register scripts
		wp_enqueue_script( 'alpha_nx_one_smoothscroll', NX_ALPHA_ONE_SCRIPTS . '/smoothscroll.js', array('jquery') ); 
		wp_enqueue_script( 'alpha_nx_one_custom', NX_ALPHA_ONE_SCRIPTS . '/custom.js', array('jquery') ); 
		wp_enqueue_script( 'alpha_nx_one_fancybox', NX_ALPHA_ONE_SCRIPTS . '/jquery.fancybox.pack.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'alpha_nx_one_fancybox', NX_ALPHA_ONE_SCRIPTS . '/fancybox.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'alpha_nx_one_html5', NX_ALPHA_ONE_SCRIPTS . '/html5.js', array( 'jquery' ), false, true );		
		
		

		// Load the stylesheets
		wp_enqueue_style( 'main-style', get_stylesheet_uri() );
		wp_enqueue_style( 'font-awesome', NX_ALPHA_ONE_STYLESHEET . '/font-awesome.css' );
		wp_enqueue_style( 'responsive', NX_ALPHA_ONE_STYLESHEET . '/responsive.css');
		wp_enqueue_style( 'fancybox-style', NX_ALPHA_ONE_STYLESHEET . '/jquery.fancybox.css' );
		
		
	}

	add_action( 'wp_enqueue_scripts', 'alpha_nx_one_header_scripts' );
}


?>